@@ -21,7 +21,7 @@
     extensions: ["tex2jax.js"],
     jax: ["input/TeX","output/HTML-CSS"],
 });
-</script><script src="http://integrativemodeling.org/mathjax/MathJax.js"></script>
+</script><script src="//integrativemodeling.org/mathjax/MathJax.js"></script>
 <link href="doxygen.css" rel="stylesheet" type="text/css" />
 <link href="salilab-doxygen.css" rel="stylesheet" type="text/css"/>
 <link href="//integrativemodeling.org/imp.css" rel="stylesheet" type="text/css"/>
@@ -61,7 +61,7 @@
  <tr style="height: 56px;">
   <td style="padding-left: 0.5em;">
    <div id="projectname">IMP Manual
-   &#160;<span id="projectnumber">for IMP version 2.5.0</span>
+   &#160;<span id="projectnumber">for IMP version 2.6.0</span>
    </div>
   </td>
  </tr>
